// Copyright 1999 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "CCConnection.h"
#import "CCTransaction.h"
#import <OmniBase/rcsid.h>
#import <OmniNetworking/OmniNetworking.h>
#import <OWF/OWURL.h>
#import <OmniFoundation/OmniFoundation.h>

RCS_ID("$Header: /Network/Source/CVS/OmniGroup/Frameworks/OmniCyberCash/CCConnection.m,v 1.4 1999/11/12 23:41:24 luke Exp $")

#define CYBERCASH_HOST @"yourhost.yourdomain.com"
#define CYBERCASH_PORT 5746

@implementation CCConnection

static CCConnection *sharedConnection = nil;
static NSCharacterSet *plusSet;

+ (void)initialize;
{
    plusSet = [[NSCharacterSet characterSetWithCharactersInString:@"+"] retain];
}

+ (CCConnection *)sharedConnection;
{

    if (!sharedConnection)
        sharedConnection = [[self alloc] init];
    return sharedConnection;
}

- init
{
    ONHost *host;
    ONTCPSocket *socket;
    
    [super init];
    socket = [ONTCPSocket tcpSocket];
    host = [ONHost hostForHostname:CYBERCASH_HOST];
    [socket connectToHost:host port:CYBERCASH_PORT];
    socketStream = [[ONSocketStream alloc] initWithSocket:socket];
    return self;
}

- (NSMutableDictionary *)parseResult:(NSString *)resultString;
{
    NSMutableDictionary *result;
    NSEnumerator *enumerator;
    NSString *keyValue;

    enumerator = [[resultString componentsSeparatedByString:@"&"] objectEnumerator];
    result = [NSMutableDictionary dictionary];
    while((keyValue = [enumerator nextObject])) {
        NSArray *parts;
        NSString *value;

        parts = [keyValue componentsSeparatedByString:@"="];
        value = [[parts objectAtIndex:1] stringByReplacingCharactersInSet:plusSet withString:@" "];
        value = [OWURL decodeURLString:value];
        [result setObject:value forKey:[OWURL decodeURLString:[parts objectAtIndex:0]]];
    }
    return result;
}

- (NSMutableDictionary *)sendMessageWithType:(NSString *)type
                                  parameters:(NSDictionary *)parameters;
{
    NSMutableString *parameterString = nil;
    NSString *key;
    NSEnumerator *enumerator;

    enumerator = [parameters keyEnumerator];
    while((key = [enumerator nextObject])) {
        NSString *encodedKey;
        NSString *encodedValue;

        encodedKey = [OWURL encodeURLString:key encoding:0 asQuery:YES leaveSlashes:NO leaveColons:NO];
        encodedValue = [OWURL encodeURLString:[parameters objectForKey:key] encoding:0 asQuery:YES leaveSlashes:NO leaveColons:NO];
        if (parameterString)
            [parameterString appendFormat:@"&%@=%@", encodedKey, encodedValue];
        else
            parameterString = [NSMutableString stringWithFormat:@"%@=%@", encodedKey, encodedValue];
    }
    [socketStream writeFormat:@"%@\n", type];
    [socketStream writeFormat:@"%@\n", parameterString];

    return [self parseResult:[socketStream readLine]];
}

- (CCTransaction *)captureCreditCardTransaction:(CCTransaction *)transaction;
{
    NSMutableDictionary *result;
    CCTransaction *resultTransaction;

    result = [self sendMessageWithType:@"mauthcapture" parameters:[transaction information]];
    resultTransaction = [[CCTransaction alloc] initWithInformation:result];
    return [resultTransaction autorelease];
}

- (void)dealloc;
{
    if (self == sharedConnection)
        sharedConnection = nil;
    [socketStream release];
    [super dealloc];
}

@end
