// Copyright 1999 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "CCTransaction.h"
#import <OmniBase/rcsid.h>
#import <ctype.h>

RCS_ID("$Header: /Network/Source/CVS/OmniGroup/Frameworks/OmniCyberCash/CCTransaction.m,v 1.3 1999/11/12 23:41:24 luke Exp $")

#define DEFAULT_CURRENCY @"usd "

@implementation CCTransaction

- initWithInformation:(NSMutableDictionary *)info;
{
    [super init];
    information = [info retain];
    return self;
}

- init;
{
    return [self initWithInformation:[NSMutableDictionary dictionary]];
}

- (void)dealloc;
{
    [information release];
    [super dealloc];
}

- (NSString *)orderID;
{
    return [information objectForKey:@"order-id"];
}

- (NSString *)note;
{
    return [information objectForKey:@"note"];
}

- (NSString *)amount;
{
    return [information objectForKey:@"amount"];
}

- (NSString *)name;
{
    return [information objectForKey:@"card-name"];
}

- (NSString *)state;
{
    return [information objectForKey:@"card-state"];
}

- (NSString *)country;
{
    return [information objectForKey:@"card-country"];
}

- (NSString *)cardNumber;
{
    return [information objectForKey:@"card-number"];
}

- (NSString *)city;
{
    return [information objectForKey:@"card-city"];
}

- (NSString *)address;
{
    return [information objectForKey:@"card-address"];
}

- (NSString *)expiration;
{
    return [information objectForKey:@"card-exp"];
}

- (NSString *)zipcode;
{
    return [information objectForKey:@"card-zip"];
}

- (NSString *)transactionType;
{
    return [information objectForKey:@"txn-type"];
}

- (NSString *)transactionStatus;
{
    return [information objectForKey:@"txn-status"];
}

- (NSString *)merchantTransactionID;
{
    return [information objectForKey:@"merch-txn"];
}

- (NSString *)messageStatus;
{
    return [information objectForKey:@"MStatus"];
}

- (NSString *)message;
{
    NSString *result;

    if (!(result = [information objectForKey:@"aux-msg"]))
        result = [information objectForKey:@"MErrMsg"];
    return result;
}

- (void)setOrderID:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"order-id"];
    else
        [information setObject:value forKey:@"order-id"];
}

- (void)setNote:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"note"];
    else
        [information setObject:value forKey:@"note"];
}

- (void)setAmount:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"amount"];
    else {
        // if it is just a number, use default currency
        if (isdigit((char)[value characterAtIndex:0]))
            value = [DEFAULT_CURRENCY stringByAppendingString:value];

        [information setObject:value forKey:@"amount"];
    }
}

- (void)setName:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-name"];
    else
        [information setObject:value forKey:@"card-name"];
}

- (void)setState:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-state"];
    else
        [information setObject:value forKey:@"card-state"];
}

- (void)setCountry:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-country"];
    else
        [information setObject:value forKey:@"card-country"];
}

- (void)setCardNumber:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-number"];
    else
        [information setObject:value forKey:@"card-number"];
}

- (void)setCity:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-city"];
    else
        [information setObject:value forKey:@"card-city"];
}

- (void)setAddress:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-address"];
    else
        [information setObject:value forKey:@"card-address"];
}

- (void)setExpiration:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-exp"];
    else
        [information setObject:value forKey:@"card-exp"];
}

- (void)setZipcode:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"card-zip"];
    else
        [information setObject:value forKey:@"card-zip"];
}

- (void)setTransactionType:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"txn-type"];
    else
        [information setObject:value forKey:@"txn-type"];
}

- (void)setTransactionStatus:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"txn-status"];
    else
        [information setObject:value forKey:@"txn-status"];
}

- (void)setMerchantTransactionID:(NSString *)value;
{
    if (![value length])
        [information removeObjectForKey:@"merch-txn"];
    else
        [information setObject:value forKey:@"merch-txn"];
}

- (NSDictionary *)information;
{
    return information;
}

@end
